@@ -5,7 +5,7 @@
 ;; Author: Precompute <git@precompute.net>
 ;; URL: https://github.com/precompute/sculpture-theme
 ;; Created: January 06, 2021
-;; Modified: January 30, 2026
+;; Modified: February 15, 2026
 
 ;; Local variables:
 ;; package-lint-main-file: "sculpture-themes.el"
@@ -162,7 +162,7 @@
    `(variable-pitch             ((,class (:height 1.0))))
    `(variable-pitch-text        ((,class (:height 1.0 :inherit variable-pitch))))
    `(sculpture-themes-dark-variable-pitch-italic      ((,class (:inherit variable-pitch :slant italic))))
-   `(fringe                     ((,class (:background ,bg))))
+   `(fringe                     ((,class (:background ,bg :foreground ,ot12))))
    `(vertical-border            ((,class (:background ,ot22 :foreground ,ot22))))
    `(window-divider             ((,class (:background ,ot22 :foreground ,ot22))))
    `(window-divider-first-pixel ((,class (:background ,cs01 :foreground ,cs01))))
@@ -680,10 +680,10 @@
    `(diff-refine-added   ((,class (:inherit bold :foreground ,bg :background ,ot01))))
 
 ;;;;;; orderless
-   `(orderless-match-face-0 ((,class (:inherit (sculpture-themes-dark-head-outline-2 bold)))))
-   `(orderless-match-face-1 ((,class (:inherit (sculpture-themes-dark-head-outline-4 bold)))))
-   `(orderless-match-face-2 ((,class (:inherit (sculpture-themes-dark-head-outline-5 bold)))))
-   `(orderless-match-face-3 ((,class (:inherit (sculpture-themes-dark-head-outline-3 bold)))))
+   `(orderless-match-face-0 ((,class (:inverse-video t :inherit (sculpture-themes-dark-head-outline-2 bold)))))
+   `(orderless-match-face-1 ((,class (:inverse-video t :inherit (sculpture-themes-dark-head-outline-4 bold)))))
+   `(orderless-match-face-2 ((,class (:inverse-video t :inherit (sculpture-themes-dark-head-outline-5 bold)))))
+   `(orderless-match-face-3 ((,class (:inverse-video t :inherit (sculpture-themes-dark-head-outline-3 bold)))))
 
 ;;;;;; ediff
    `(ediff-odd-diff-Ancestor ((,class (:background ,ot06))))
